==> core-react-0.8.0.tgz: package/es/Pager/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import { Row } from '../Layout';


var Pager = /*#__PURE__*/function (_React$Component) {
  _inherits(Pager, _React$Component);

  function Pager(props) {
    var _this;

    _classCallCheck(this, Pager);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Pager).call(this));

    _defineProperty(_assertThisInitialized(_this), "createPageEl", function (num, key) {
      key = key || num;
      var active = "".concat("waui", "-pager__pagination-li--active");
      var isActive = _this.state.currentIndex === num ? active : '';
      return React.createElement("li", {
        key: key,
        className: isActive,
        onClick: _this.handleClick.bind(_assertThisInitialized(_this), num)
      }, React.createElement("a", null, num));
    });

    _defineProperty(_assertThisInitialized(_this), "handlePrevClick", function () {
      if (_this.state.currentIndex > 1) {
        _this.setState({
          currentIndex: _this.state.currentIndex - 1
        });

        if (_this.props.onSelect) {
          _this.props.onSelect(parseInt(_this.state.currentIndex - 1));
        }
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleNextClick", function () {
      var pageNum = Math.ceil(_this.props.totalItems / _this.props.itemsPerPage);

      if (_this.state.currentIndex < pageNum) {
        _this.setState({
          currentIndex: _this.state.currentIndex + 1
        });

        if (_this.props.onSelect) {
          _this.props.onSelect(parseInt(_this.state.currentIndex + 1));
        }
      }
    });

    _this.state = {
      currentIndex: props.currentPage,
      showPage: props.maxSerialPages || 4,
      goPageNum: ''
    };
    return _this;
  }

  _createClass(Pager, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (this.props.currentPage !== nextProps.currentPage) {
        this.setState({
          currentIndex: nextProps.currentPage
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var pageNum = Math.ceil(this.props.totalItems / this.props.itemsPerPage);
      var currentIndex = this.state.currentIndex;
      return React.createElement(Row, null, React.createElement("div", {
        className: "".concat("waui", "-pager__layout-middle")
      }, React.createElement("ul", {
        className: "".concat("waui", "-pager__pagination")
      }, React.createElement("li", null, React.createElement("a", {
        onClick: this.handlePrevClick,
        className: "".concat("waui", "-pager__pagination-li--prev ") + (currentIndex === 1 ? "".concat("waui", "-pager__pagination-li--first") : '')
      }, React.createElement("svg", {
        xmlns: "http://www.w3.org/2000/svg",
        width: "20",
        height: "20",
        lineheight: "20",
        viewBox: "0 0 24 24"
      }, React.createElement("path", {
        d: "M11 18V6l-8.5 6 8.5 6zm.5-6l8.5 6V6l-8.5 6z"
      })))), this.getPages(currentIndex, pageNum), React.createElement("li", null, React.createElement("a", {
        onClick: this.handleNextClick,
        className: "".concat("waui", "-pager__pagination-li--next ") + (currentIndex === pageNum ? "".concat("waui", "-pager__pagination-li--end") : '')
      }, React.createElement("svg", {
        xmlns: "http://www.w3.org/2000/svg",
        width: "20",
        height: "20",
        lineheight: "20",
        viewBox: "0 0 24 24"
      }, React.createElement("path", {
        d: "M4 18l8.5-6L4 6v12zm9-12v12l8.5-6L13 6z"
      })))))));
    }
  }, {
    key: "getPages",
    value: function getPages(currentPage, maxPage) {
      var pages = [];
      var showPage = this.state.showPage;

      if (maxPage <= showPage + 2) {
        for (var i = 1; i <= maxPage; i++) {
          var html = this.createPageEl(i);
          pages.push(html);
        }
      } else {
        if (currentPage < showPage) {
          for (var _i = 1; _i <= showPage + 2 && _i <= maxPage; _i++) {
            var _html = this.createPageEl(_i);

            if (_i < maxPage - 1 && _i === showPage + 1) {
              var dotsHtml = React.createElement("li", {
                key: 'd' + _i
              }, React.createElement("span", null, "..."));
              pages.push(dotsHtml);
            } else {
              if (_i === showPage + 2) {
                pages.push(this.createPageEl(maxPage, +new Date()));
              } else {
                pages.push(_html);
              }
            }
          }
        } else if (currentPage >= showPage && currentPage + showPage <= maxPage + 1) {
          pages[0] = this.createPageEl(1);

          if (currentPage === 3) {
            pages[1] = this.createPageEl(2);
          } else {
            pages[1] = React.createElement("li", {
              key: "d1"
            }, React.createElement("span", null, "..."));
          }

          var _i2 = currentPage + 1 - parseInt(showPage / 2);

          for (; _i2 < currentPage + parseInt(showPage / 2); _i2++) {
            var _html2 = this.createPageEl(_i2);

            pages.push(_html2);
          }

          pages.push(React.createElement("li", {
            key: 'd' + _i2
          }, React.createElement("span", null, "...")));
          pages.push(this.createPageEl(maxPage));
        } else {
          pages[0] = this.createPageEl(1);
          pages[1] = React.createElement("li", {
            key: "d1"
          }, React.createElement("span", null, "..."));
          var _i3 = currentPage;

          if (maxPage - currentPage < showPage - 1) {
            _i3 = currentPage - (showPage - 1 - (maxPage - currentPage));
          }

          for (; _i3 <= maxPage; _i3++) {
            var _html3 = this.createPageEl(_i3);

            pages.push(_html3);
          }
        }
      }

      return pages;
    }
  }, {
    key: "handleClick",
    value: function handleClick(i) {
      this.setState({
        currentIndex: i
      });

      if (this.props.onSelect) {
        this.props.onSelect(i);
      }
    } // handleGoPage = () => {
    //   let number = parseInt(this.state.goPageNum) || this.state.currentIndex
    //   const pageNum = Math.ceil(this.props.totalItems / this.props.itemsPerPage)
    //
    //   if (number <= 0) {
    //     number = 1
    //   } else if (number > pageNum) {
    //     number = pageNum
    //   }
    //
    //   this.setState({
    //     currentIndex: number
    //   })
    //
    //   number !== this.state.currentIndex && this.props.onSelect && this.props.onSelect(number)
    // }
    // checkNumber = (e) => {
    //   const value = e.target.value
    //   const numberReg = /^\+?[1-9][0-9]*$/
    //   if (!numberReg.test(value)) {
    //     this.setState({
    //       goPageNum: ''
    //     })
    //   } else {
    //     this.setState({
    //       goPageNum: value
    //     })
    //   }
    // }

  }]);

  return Pager;
}(React.Component);

Pager.defaultProps = {
  currentPage: 1,
  itemsPerPage: 20 // hideGo: true

};
Pager.propTypes = {
  /** Total count of items */
  totalItems: PropTypes.number.isRequired,

  /** The count of items per page, default value is `20` */
  itemsPerPage: PropTypes.number,

  /** Current page number, starting with `1`, default value is `1` */
  currentPage: PropTypes.number,

  /** Maximum number of consecutive page Numbers displayed, default value is `4` */
  maxSerialPages: PropTypes.number,

  /** The event of the selected page number, param is the the of selected page */
  onSelect: PropTypes.func
};
export default Pager;

==> core-react-0.8.2.tgz: package/es/Pager/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import { Row } from '../Layout';


var Pager = /*#__PURE__*/function (_React$Component) {
  _inherits(Pager, _React$Component);

  function Pager(props) {
    var _this;

    _classCallCheck(this, Pager);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Pager).call(this));

    _defineProperty(_assertThisInitialized(_this), "createPageEl", function (num, key) {
      key = key || num;
      var active = "".concat("waui", "-pager__pagination-li--active");
      var isActive = _this.state.currentIndex === num ? active : '';
      return (/*#__PURE__*/React.createElement("li", {
          key: key,
          className: isActive,
          onClick: _this.handleClick.bind(_assertThisInitialized(_this), num)
        }, /*#__PURE__*/React.createElement("a", null, num))
      );
    });

    _defineProperty(_assertThisInitialized(_this), "handlePrevClick", function () {
      if (_this.state.currentIndex > 1) {
        _this.setState({
          currentIndex: _this.state.currentIndex - 1
        });

        if (_this.props.onSelect) {
          _this.props.onSelect(parseInt(_this.state.currentIndex - 1));
        }
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleNextClick", function () {
      var pageNum = Math.ceil(_this.props.totalItems / _this.props.itemsPerPage);

      if (_this.state.currentIndex < pageNum) {
        _this.setState({
          currentIndex: _this.state.currentIndex + 1
        });

        if (_this.props.onSelect) {
          _this.props.onSelect(parseInt(_this.state.currentIndex + 1));
        }
      }
    });

    _this.state = {
      currentIndex: props.currentPage,
      showPage: props.maxSerialPages || 4,
      goPageNum: ''
    };
    return _this;
  }

  _createClass(Pager, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (this.props.currentPage !== nextProps.currentPage) {
        this.setState({
          currentIndex: nextProps.currentPage
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var pageNum = Math.ceil(this.props.totalItems / this.props.itemsPerPage);
      var currentIndex = this.state.currentIndex;
      return (/*#__PURE__*/React.createElement(Row, null, /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-pager__layout-middle")
        }, /*#__PURE__*/React.createElement("ul", {
          className: "".concat("waui", "-pager__pagination")
        }, /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement("a", {
          onClick: this.handlePrevClick,
          className: "".concat("waui", "-pager__pagination-li--prev ") + (currentIndex === 1 ? "".concat("waui", "-pager__pagination-li--first") : '')
        }, /*#__PURE__*/React.createElement("svg", {
          xmlns: "http://www.w3.org/2000/svg",
          width: "20",
          height: "20",
          lineheight: "20",
          viewBox: "0 0 24 24"
        }, /*#__PURE__*/React.createElement("path", {
          d: "M11 18V6l-8.5 6 8.5 6zm.5-6l8.5 6V6l-8.5 6z"
        })))), this.getPages(currentIndex, pageNum), /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement("a", {
          onClick: this.handleNextClick,
          className: "".concat("waui", "-pager__pagination-li--next ") + (currentIndex === pageNum ? "".concat("waui", "-pager__pagination-li--end") : '')
        }, /*#__PURE__*/React.createElement("svg", {
          xmlns: "http://www.w3.org/2000/svg",
          width: "20",
          height: "20",
          lineheight: "20",
          viewBox: "0 0 24 24"
        }, /*#__PURE__*/React.createElement("path", {
          d: "M4 18l8.5-6L4 6v12zm9-12v12l8.5-6L13 6z"
        })))))))
      );
    }
  }, {
    key: "getPages",
    value: function getPages(currentPage, maxPage) {
      var pages = [];
      var showPage = this.state.showPage;

      if (maxPage <= showPage + 2) {
        for (var i = 1; i <= maxPage; i++) {
          var html = this.createPageEl(i);
          pages.push(html);
        }
      } else {
        if (currentPage < showPage) {
          for (var _i = 1; _i <= showPage + 2 && _i <= maxPage; _i++) {
            var _html = this.createPageEl(_i);

            if (_i < maxPage - 1 && _i === showPage + 1) {
              var dotsHtml = /*#__PURE__*/React.createElement("li", {
                key: 'd' + _i
              }, /*#__PURE__*/React.createElement("span", null, "..."));
              pages.push(dotsHtml);
            } else {
              if (_i === showPage + 2) {
                pages.push(this.createPageEl(maxPage, +new Date()));
              } else {
                pages.push(_html);
              }
            }
          }
        } else if (currentPage >= showPage && currentPage + showPage <= maxPage + 1) {
          pages[0] = this.createPageEl(1);

          if (currentPage === 3) {
            pages[1] = this.createPageEl(2);
          } else {
            pages[1] = /*#__PURE__*/React.createElement("li", {
              key: "d1"
            }, /*#__PURE__*/React.createElement("span", null, "..."));
          }

          var _i2 = currentPage + 1 - parseInt(showPage / 2);

          for (; _i2 < currentPage + parseInt(showPage / 2); _i2++) {
            var _html2 = this.createPageEl(_i2);

            pages.push(_html2);
          }

          pages.push( /*#__PURE__*/React.createElement("li", {
            key: 'd' + _i2
          }, /*#__PURE__*/React.createElement("span", null, "...")));
          pages.push(this.createPageEl(maxPage));
        } else {
          pages[0] = this.createPageEl(1);
          pages[1] = /*#__PURE__*/React.createElement("li", {
            key: "d1"
          }, /*#__PURE__*/React.createElement("span", null, "..."));
          var _i3 = currentPage;

          if (maxPage - currentPage < showPage - 1) {
            _i3 = currentPage - (showPage - 1 - (maxPage - currentPage));
          }

          for (; _i3 <= maxPage; _i3++) {
            var _html3 = this.createPageEl(_i3);

            pages.push(_html3);
          }
        }
      }

      return pages;
    }
  }, {
    key: "handleClick",
    value: function handleClick(i) {
      this.setState({
        currentIndex: i
      });

      if (this.props.onSelect) {
        this.props.onSelect(i);
      }
    } // handleGoPage = () => {
    //   let number = parseInt(this.state.goPageNum) || this.state.currentIndex
    //   const pageNum = Math.ceil(this.props.totalItems / this.props.itemsPerPage)
    //
    //   if (number <= 0) {
    //     number = 1
    //   } else if (number > pageNum) {
    //     number = pageNum
    //   }
    //
    //   this.setState({
    //     currentIndex: number
    //   })
    //
    //   number !== this.state.currentIndex && this.props.onSelect && this.props.onSelect(number)
    // }
    // checkNumber = (e) => {
    //   const value = e.target.value
    //   const numberReg = /^\+?[1-9][0-9]*$/
    //   if (!numberReg.test(value)) {
    //     this.setState({
    //       goPageNum: ''
    //     })
    //   } else {
    //     this.setState({
    //       goPageNum: value
    //     })
    //   }
    // }

  }]);

  return Pager;
}(React.Component);

Pager.defaultProps = {
  currentPage: 1,
  itemsPerPage: 20 // hideGo: true

};
Pager.propTypes = {
  /** Total count of items */
  totalItems: PropTypes.number.isRequired,

  /** The count of items per page, default value is `20` */
  itemsPerPage: PropTypes.number,

  /** Current page number, starting with `1`, default value is `1` */
  currentPage: PropTypes.number,

  /** Maximum number of consecutive page Numbers displayed, default value is `4` */
  maxSerialPages: PropTypes.number,

  /** The event of the selected page number, param is the the of selected page */
  onSelect: PropTypes.func
};
export default Pager;
